Node Classification
===================
.. automodule:: networkx.algorithms.node_classification
.. currentmodule:: networkx

Harmonic Function
-----------------
.. automodule:: networkx.algorithms.node_classification.hmn
.. autosummary::
   :toctree: generated/

   harmonic_function


Local and Global Consistency
----------------------------
.. automodule:: networkx.algorithms.node_classification.lgc
.. autosummary::
   :toctree: generated/

   local_and_global_consistency
